@@ -35,7 +35,7 @@ class DatabaseDAO(DAOBase):
         databases = []
 
         limit = 20
-        fields = ["id", "host", "porta", "nome", "tenant", "user", "password"]
+        fields = ["id", "host", "porta", "nome", "tenant", '"user"', "password"]
         response = self.list(after=None, limit=limit, fields=fields, order_fields=None, filters=None)
         databases += response
 
