@@ -25,8 +25,13 @@ def multi_database():
                 with InjectorFactory() as factory:
                     database_dao = factory.database_dao()
 
-                    # Recuperando o tenant da query string
+                    # Recuperando o tenant da query string, ou do corpo da requisição
                     tenant = request.args.get('tenant')
+                    if tenant is None:
+                        if request.headers.get("Content-type").lower() == "application/json":
+                            body = request.json
+                            tenant = body["tenant"]
+
                     if tenant is None:
                         raise ParameterNotFound('tenant')
 
@@ -51,7 +56,7 @@ def multi_database():
                         # Decypt user and password
                         user = decrypt(database["user"])
                         password = decrypt(database["password"])
-                    
+
                 if user is None or password is None:
                     with InjectorFactory(use_external_db_with_default_credentials=True) as factory:
                         usuario_dao = factory.usuario_dao()
@@ -61,14 +66,18 @@ def multi_database():
                         user = __get_db_username(
                             g.external_database["name"], usuario["login"])
                         password = usuario["senha"]
-                
+
                 # Gravando usuario e senha na variável g do Flask
                 g.external_database["user"] = user
                 g.external_database["password"] = password
 
                 return func(*args, **kwargs)
             except ParameterNotFound as e:
-                msg = f"Faltando parâmetro obrigatório na requisição: {e}."
+                if request.method.upper() == 'GET':
+                    msg = f"Faltando parâmetro obrigatório na requisição: {e}."
+                else:
+                    msg = f"Faltando propriedade obrigatória no corpo da requisição: {e}."
+
                 get_logger().warning(msg)
                 return (format_json_error(msg), 400, {"Content-Type": "application/json; charset=utf-8"})
             except Exception as e:
